.. image:: https://odoo-community.org/readme-banner-image
   :target: https://odoo-community.org/get-involved?utm_source=readme
   :alt: Odoo Community Association

==========
Statechart
==========

.. 
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! This file is generated by oca-gen-addon-readme !!
   !! changes will be overwritten.                   !!
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! source digest: sha256:63949f6cfdabc7f7e60a2b3d75f934f75c6024666a807e4e916a56bd23a09ec9
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

.. |badge1| image:: https://img.shields.io/badge/maturity-Beta-yellow.png
    :target: https://odoo-community.org/page/development-status
    :alt: Beta
.. |badge2| image:: https://img.shields.io/badge/license-LGPL--3-blue.png
    :target: http://www.gnu.org/licenses/lgpl-3.0-standalone.html
    :alt: License: LGPL-3
.. |badge3| image:: https://img.shields.io/badge/github-acsone%2Fscobidoo-lightgray.png?logo=github
    :target: https://github.com/acsone/scobidoo/tree/16.0/statechart
    :alt: acsone/scobidoo

|badge1| |badge2| |badge3|

Add statecharts to Odoo models.

**Table of contents**

.. contents::
   :local:

Usage
=====

There is no documentation yet. In the meantime here are the Odoo
Experience 2018
`slides <https://docs.google.com/presentation/d/e/2PACX-1vR9VGsSQUnITdnQq5KRiWnY7o-yERCB8YfnqxzhFW5tFcJ8AzMmIQ1CpLTdEgy5Sz9nx-yQlC0BhyGR/pub?start=false&loop=false&delayms=3000>`__
and `video <https://www.youtube.com/watch?v=ssgl0kraOMc>`__ which should
get you started.

See also the `sismic
documentation <https://sismic.readthedocs.io/en/latest/>`__.

Bug Tracker
===========

Bugs are tracked on `GitHub Issues <https://github.com/acsone/scobidoo/issues>`_.
In case of trouble, please check there if your issue has already been reported.
If you spotted it first, help us to smash it by providing a detailed and welcomed
`feedback <https://github.com/acsone/scobidoo/issues/new?body=module:%20statechart%0Aversion:%2016.0%0A%0A**Steps%20to%20reproduce**%0A-%20...%0A%0A**Current%20behavior**%0A%0A**Expected%20behavior**>`_.

Do not contact contributors directly about support or help with technical issues.

Credits
=======

Authors
-------

* ACSONE SA/NV

Maintainers
-----------

This module is part of the `acsone/scobidoo <https://github.com/acsone/scobidoo/tree/16.0/statechart>`_ project on GitHub.

You are welcome to contribute.
